@@ -113,10 +113,18 @@ class LiveClient(WebSocketApp):
                         self.parent_app.live_data[ticker_id].day_low = self.parent_app.touchline_data[ticker_id].low = ltp
                 self.parent_app.live_data[ticker_id].tick_seq = int(trade_tick[8])
                 # Calculating addn data
-                self.parent_app.live_data[ticker_id].oi_change = self.parent_app.live_data[ticker_id].oi - self.parent_app.live_data[ticker_id].prev_day_oi
-                self.parent_app.live_data[ticker_id].oi_change_perc = self.parent_app.live_data[ticker_id].oi_change * 100 / self.parent_app.live_data[ticker_id].prev_day_oi
-                self.parent_app.live_data[ticker_id].change = self.parent_app.live_data[ticker_id].ltp - self.parent_app.live_data[ticker_id].prev_day_close
-                self.parent_app.live_data[ticker_id].change_perc = self.parent_app.live_data[ticker_id].change * 100 / self.parent_app.live_data[ticker_id].prev_day_close
+                try:
+                    self.parent_app.live_data[ticker_id].oi_change = self.parent_app.live_data[ticker_id].oi - self.parent_app.live_data[ticker_id].prev_day_oi
+                    self.parent_app.live_data[ticker_id].oi_change_perc = self.parent_app.live_data[ticker_id].oi_change * 100 / self.parent_app.live_data[ticker_id].prev_day_oi
+                except ZeroDivisionError:
+                    self.parent_app.live_data[ticker_id].oi_change = 0
+                    self.parent_app.live_data[ticker_id].oi_change_perc = 0
+                try:
+                    self.parent_app.live_data[ticker_id].change = self.parent_app.live_data[ticker_id].ltp - self.parent_app.live_data[ticker_id].prev_day_close
+                    self.parent_app.live_data[ticker_id].change_perc = self.parent_app.live_data[ticker_id].change * 100 / self.parent_app.live_data[ticker_id].prev_day_close
+                except ZeroDivisionError:
+                    self.parent_app.live_data[ticker_id].change = 0
+                    self.parent_app.live_data[ticker_id].change_perc = 0
                 try:
                     self.parent_app.live_data[ticker_id].best_bid_price = float(trade_tick[9])
                     self.parent_app.live_data[ticker_id].best_bid_qty = int(trade_tick[10])
@@ -162,10 +170,18 @@ class LiveClient(WebSocketApp):
                 self.parent_app.live_data[ticker_id].volume = float(bar_data[6])
                 self.parent_app.live_data[ticker_id].oi = float(bar_data[7])
                 # Calculating addn data
-                self.parent_app.live_data[ticker_id].oi_change = self.parent_app.live_data[ticker_id].oi - self.parent_app.live_data[ticker_id].prev_day_oi
-                self.parent_app.live_data[ticker_id].oi_change_perc = self.parent_app.live_data[ticker_id].oi_change * 100 / self.parent_app.live_data[ticker_id].prev_day_oi
-                self.parent_app.live_data[ticker_id].change = self.parent_app.live_data[ticker_id].close - self.parent_app.live_data[ticker_id].prev_day_close
-                self.parent_app.live_data[ticker_id].change_perc = self.parent_app.live_data[ticker_id].change * 100 / self.parent_app.live_data[ticker_id].prev_day_close
+                try:
+                    self.parent_app.live_data[ticker_id].oi_change = self.parent_app.live_data[ticker_id].oi - self.parent_app.live_data[ticker_id].prev_day_oi
+                    self.parent_app.live_data[ticker_id].oi_change_perc = self.parent_app.live_data[ticker_id].oi_change * 100 / self.parent_app.live_data[ticker_id].prev_day_oi
+                except ZeroDivisionError:
+                    self.parent_app.live_data[ticker_id].oi_change = 0
+                    self.parent_app.live_data[ticker_id].oi_change_perc = 0
+                try:
+                    self.parent_app.live_data[ticker_id].change = self.parent_app.live_data[ticker_id].close - self.parent_app.live_data[ticker_id].prev_day_close
+                    self.parent_app.live_data[ticker_id].change_perc = self.parent_app.live_data[ticker_id].change * 100 / self.parent_app.live_data[ticker_id].prev_day_close
+                except ZeroDivisionError:
+                    self.parent_app.live_data[ticker_id].change = 0
+                    self.parent_app.live_data[ticker_id].change_perc = 0
         except KeyError:
             print(f'{Style.BRIGHT}{Fore.RED}This symbol is not tied to any req_id...{Style.RESET_ALL}')
 
@@ -187,6 +203,7 @@ class HistoricalWebsocket:
             print(f"Connected successfully to {welcome_msg['message']}")
         else:
             print(f"{Style.BRIGHT}{Fore.RED}Failed to connect with error message = {welcome_msg['message']}{Style.RESET_ALL}")
+            self.hist_socket.close()
 
     def get_hist_bar_data(self, contract, query_time, start_time, bar_size):
         # print(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{query_time}"}}')
